---
title: "MCP9808"
linkTitle: "MCP9808"
weight: 4
description: >
  This is a test description
---

## Registers

### Configuration Register
The MCP9808 has a 16-bit Configuration register (CONFIG) that
allows the user to set various functions for a robust temperature
monitoring system.
Bits 10 through 0 are used to select the temperature alert output
hysteresis, device shutdown or Low-Power mode, temperature boundary
and critical temperature lock, and temperature Alert output
enable/disable.
In addition, Alert output condition (output set for TUPPER and
TLOWER temperature boundary or TCRIT only), Alert output status
and Alert output polarity and mode (Comparator Output or Interrupt
Output mode) are user-configurable.


## License
Licensed under [Apache-2.0](https://spdx.org/licenses/Apache-2.0.html#licenseText).

_MCP9808 version 0.1.0_

_Based on Cyanobyte spec version 0.1.0_

_Generated from Cyanobyte Codegen version 0.1.0_